@@ -234,7 +234,7 @@ def push(data, code, name, authtoken='', desc='', override=False, verbose=False,
         error = ("Server Error. We apologize, something went wrong on our end. Please try call again in a minute, and email us at connect@quandl.com if this error persists.")
         raise QuandlError(error)
     else:
-        error = ("Unknown response ({r}). Please copy and paste the error output, and the file you are running, and email us at connect@quandl.com. We will help you fix your error ASAP.".format(str(resp.status_code))
+        error = ("Unknown response ({r}). Please copy and paste the error output, and the file you are running, and email us at connect@quandl.com. We will help you fix your error ASAP.".format(str(resp.status_code)))
         raise UnknownError(error)
 
 
@@ -415,3 +415,13 @@ class DateNotRecognized(Exception):
 class CodeFormatError(Exception):
     """Exception when a Quandl code is not formatted properly"""
     pass
+
+class QuandlError(Exception):
+    """ Exception when something is wrong with Quandl"""
+    pass
+class TokenError(Exception):
+    """Exception when incorrect API token is given"""
+    pass
+class UnknownError(Exception):
+    """Exception when an unknown error is passed"""
+    pass
\ No newline at end of file
